@@ -399,10 +399,11 @@ which(pmatN < 0.05, arr.ind=TRUE) # => none (so the margins cause non-normality
 which(pmatt < 0.05, arr.ind=TRUE) # => none (fine)
 
 ## testing *multivariate normality*
-stopifnot(require(mvnormtest))
-mshapiro.test(t(x)) ## => *not* a multivariate normal distribution
-mshapiro.test(t(qnorm(u)))
-## => also not a Gauss copula after removing marginal non-Gaussianity
+if(require("mvnormtest")) withAutoprint({
+  mshapiro.test(t(x)) ## => *not* a multivariate normal distribution
+  mshapiro.test(t(qnorm(u)))
+  ## => also not a Gauss copula after removing marginal non-Gaussianity
+})
 
 ## Well, look at the 1D margins :
 print(Pm <- apply(x, 2, function(u) shapiro.test(u)$p.value))
@@ -425,4 +426,4 @@ if(doPDF) pdf(file=(file <- "gof_graph_fig-SMI-ex.pdf"))
 pairsRosenblatt(cu.ut, pvalueMat=pmatt, method="none", cex.labels=0.7,
                 key.space=1.5, main.centered=TRUE, main=title, line.main=c(3, 0.4),
                 keyOpt=list(space=1.5, width=1.5, axis=TRUE, title=NULL, line=5))
-if(doPDF) dev.off()
\ No newline at end of file
+if(doPDF) dev.off()
